<?php

// Démarrer la session PHP (si nécessaire pour la journalisation utilisateur, sinon peut être omis)
session_start();

// Inclusion des fichiers fondamentaux
require_once __DIR__ . '/../src/Core/Autoloader.php';
require_once __DIR__ . '/../src/Core/Database.php';
require_once __DIR__ . '/../src/config/app.php'; // Charge les constantes d'application

// Enregistrement de l'autoloader
\App\Core\Autoloader::register();

// Importation des classes
use App\Core\Database;
use App\Controllers\OcspController; // Votre contrôleur spécifique pour l'OCSP
use App\Services\AuthService;
use App\Services\LogService;

// Initialisation de la connexion à la base de données (si le contrôleur OCSP en a besoin)
try {
    Database::connect(DB_HOST, DB_NAME, DB_USER, DB_PASSWORD);
} catch (PDOException $e) {
    error_log("OCSP: Database connection error: " . $e->getMessage());
    http_response_code(500);
    die("OCSP service temporarily unavailable.");
}

$dbInstance = Database::getInstance();
$authService = new AuthService($dbInstance); // Peut être utilisé pour logguer des requêtes OCSP anonymes
$logService = new LogService(APP_LOG_PATH);


// La logique OCSP réelle serait plus complexe.
// Ce script attendrait une requête POST OCSP (application/ocsp-request)
// et appellerait le contrôleur OCSP pour la traiter.

// Pour un POC, nous allons simplement appeler la méthode du contrôleur dédiée.
// En production, Nginx redirigerait une requête HTTP POST spécifique vers ce script.
// Le client OCSP enverrait une requête binaire.
// Pour l'instant, ce script est juste un point d'entrée.

$controller = new OcspController();
$controller->handleRequest();

// Log la requête OCSP
$logService->log('info', 'Requête OCSP reçue.', null, $_SERVER['REMOTE_ADDR']);
