<?php

namespace App\Controllers;

use App\Core\Database;
use App\Services\AuthService;
use App\Services\LanguageService;
use App\Utils\DarkMode;

/**
 * Contrôleur pour la page d'accueil.
 * Redirige vers le tableau de bord si l'utilisateur est déjà connecté.
 */
class HomeController
{
    private $authService;
    private $langService;

    /**
     * Constructeur du HomeController.
     */
    public function __construct()
    {
        $this->authService = new AuthService(Database::getInstance());
        $this->langService = new LanguageService(APP_ROOT_DIR . '/src/Lang/');
    }

    /**
     * Affiche la page d'accueil ou redirige.
     */
    public function index()
    {
        // Si l'utilisateur est déjà connecté, le rediriger vers le tableau de bord
        if ($this->authService->isLoggedIn()) {
            header('Location: /dashboard');
            exit();
        }

        // Sinon, afficher la page de connexion
        // On réutilise la logique de showLoginForm de AuthController pour éviter la duplication.
        // On pourrait aussi faire un require de la vue directement.
        $authController = new AuthController();
        $authController->showLoginForm();
    }
}
