<?php
// Variables attendues du contrôleur: $users, $translations, $currentLang, $darkModeClass, $successMessage, $errorMessage, $authService (pour getUserId)
require_once APP_ROOT_DIR . '/src/Views/shared/header.php';
?>

    <div class="container">
        <h1><?= htmlspecialchars($translations['users']) ?></h1>
        <div class="actions-bar">
            <a href="/dashboard" class="button secondary-button"><?= htmlspecialchars($translations['back_to_dashboard']) ?></a>
            <a href="/users/create" class="button primary-button"><?= htmlspecialchars($translations['create_new_user']) ?></a>
        </div>

        <?php if (isset($successMessage)): ?>
            <p class="success-message"><?= htmlspecialchars($successMessage); ?></p>
        <?php endif; ?>
        <?php if (isset($errorMessage)): ?>
            <p class="error-message"><?= htmlspecialchars($errorMessage); ?></p>
        <?php endif; ?>

        <?php if (empty($users)): ?>
            <p><?= htmlspecialchars($translations['no_users_yet']) ?></p>
        <?php else: ?>
            <div class="table-responsive">
                <table>
                    <thead>
                        <tr>
                            <th><?= htmlspecialchars($translations['username']) ?></th>
                            <th><?= htmlspecialchars($translations['user_role']) ?></th>
                            <th><?= htmlspecialchars($translations['created_at']) ?></th>
                            <th><?= htmlspecialchars($translations['actions']) ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($users as $user): ?>
                            <tr>
                                <td><?= htmlspecialchars($user['username']) ?></td>
                                <td><?= htmlspecialchars($translations[$user['role']] ?? $user['role']) ?></td>
                                <td><?= htmlspecialchars((new DateTime($user['created_at']))->format('Y-m-d H:i:s')) ?></td>
                                <td class="actions-cell"> <!-- Ajout d'une classe pour styliser si besoin -->
                                    <?php if ($user['username'] !== 'admin' && $user['id'] !== $authService->getUserId()): ?>
                                        <form action="/users/toggle-admin" method="post" class="inline-form" onsubmit="return confirm('<?= htmlspecialchars($translations['confirm_toggle_admin_role'] ?? 'Êtes-vous sûr de vouloir modifier le rôle de cet utilisateur ?') ?>');">
                                            <input type="hidden" name="user_id" value="<?= htmlspecialchars($user['id']) ?>">
                                            <?php if ($user['role'] === 'admin'): ?>
                                                <button type="submit" class="button warning-button"><?= htmlspecialchars($translations['remove_admin_status'] ?? 'Retirer Admin') ?></button>
                                            <?php else: ?>
                                                <button type="submit" class="button primary-button"><?= htmlspecialchars($translations['pass_to_admin'] ?? 'Passer Admin') ?></button>
                                            <?php endif; ?>
                                        </form>
                                    <?php elseif ($user['username'] === 'admin'): ?>
                                        <em><?= htmlspecialchars($translations['cannot_change_main_admin_role'] ?? 'Rôle non modifiable') ?></em>
                                    <?php endif; ?>

                                    <?php if ($user['id'] !== $authService->getUserId() && $user['username'] !== 'admin'): // Condition existante pour la suppression, légèrement ajustée pour être sûr que 'admin' n'est pas supprimable non plus via cette interface ?>
                                        <form action="/users/delete" method="post" class="inline-form" onsubmit="return confirm('<?= htmlspecialchars($translations['confirm_delete_user']) ?>');">
                                            <input type="hidden" name="user_id" value="<?= htmlspecialchars($user['id']) ?>">
                                            <button type="submit" class="button danger-button"><?= htmlspecialchars($translations['delete_user']) ?></button>
                                        </form>
                                    <?php elseif ($user['id'] === $authService->getUserId() && $user['username'] !== 'admin'): // Permet à l'admin de voir "non modifiable" pour lui meme, mais pas "auto suppression interdite" si c'est admin ?>
                                        <em><?= htmlspecialchars($translations['self_delete_not_allowed']) ?></em>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php endif; ?>
    </div>

<?php
require_once APP_ROOT_DIR . '/src/Views/shared/footer.php';
?>
